EXPORTS
	?Discover@RPnPServiceDiscovery@@QAEXABVRPnPParameterBundle@@@Z @ 1 NONAME ; void RPnPServiceDiscovery::Discover(class RPnPParameterBundle const &)
	?Cancel@RPnPServiceDiscovery@@QAEXABVRPnPParameterBundle@@@Z @ 2 NONAME ; void RPnPServiceDiscovery::Cancel(class RPnPParameterBundle const &)
	?MessageDes@TControlMessage@@QBEABVTDesC8@@XZ @ 3 NONAME ; class TDesC8 const & TControlMessage::MessageDes(void) const
	?SetLast@TControlMessage@@QAEXXZ @ 4 NONAME ; void TControlMessage::SetLast(void)
	?IsLast@TControlMessage@@QBEHXZ @ 5 NONAME ; int TControlMessage::IsLast(void) const
	?Open@RPnPParameterBundleBase@@QAEHXZ @ 6 NONAME ; int RPnPParameterBundleBase::Open(void)
	??1CPnPServicePublisherBase@@UAE@XZ @ 7 NONAME ; CPnPServicePublisherBase::~CPnPServicePublisherBase(void)
	?SetMaxLength@TControlMessage@@QAEXH@Z @ 8 NONAME ; void TControlMessage::SetMaxLength(int)
	??0RPnPServiceDiscovery@@QAE@XZ @ 9 NONAME ; RPnPServiceDiscovery::RPnPServiceDiscovery(void)
	?Open@RPnPServiceDiscovery@@QAEHI@Z @ 10 NONAME ; int RPnPServiceDiscovery::Open(unsigned int)
	?Close@RPnPParameterBundleBase@@QAEXXZ @ 11 NONAME ; void RPnPParameterBundleBase::Close(void)
	??0CPnPServiceDiscoveryBase@@IAE@XZ @ 12 NONAME ; CPnPServiceDiscoveryBase::CPnPServiceDiscoveryBase(void)
	?MaxLength@TControlMessage@@QBEHXZ @ 13 NONAME ; int TControlMessage::MaxLength(void) const
	?SendNotify@RPnPServicePublisher@@QAEXABVRPnPParameterBundle@@@Z @ 14 NONAME ; void RPnPServicePublisher::SendNotify(class RPnPParameterBundle const &)
	?Close@RControlChannel@@QAEXXZ @ 15 NONAME ; void RControlChannel::Close(void)
	?ClearFlags@TControlMessage@@QAEXXZ @ 16 NONAME ; void TControlMessage::ClearFlags(void)
	?Recv@RControlChannel@@QAEXAAVTControlMessage@@AAVTRequestStatus@@@Z @ 17 NONAME ; void RControlChannel::Recv(class TControlMessage &, class TRequestStatus &)
	?CancelSend@RControlChannel@@QAEXXZ @ 18 NONAME ; void RControlChannel::CancelSend(void)
	??1CPnPServiceDiscoveryBase@@UAE@XZ @ 19 NONAME ; CPnPServiceDiscoveryBase::~CPnPServiceDiscoveryBase(void)
	?Close@RPnPServicePublisher@@QAEXXZ @ 20 NONAME ; void RPnPServicePublisher::Close(void)
	?Subscribe@RPnPServiceDiscovery@@QAEXABVRPnPParameterBundle@@@Z @ 21 NONAME ; void RPnPServiceDiscovery::Subscribe(class RPnPParameterBundle const &)
	?Publish@RPnPServicePublisher@@QAEXABVRPnPParameterBundle@@@Z @ 22 NONAME ; void RPnPServicePublisher::Publish(class RPnPParameterBundle const &)
	?Open@RPnPServicePublisher@@QAEHI@Z @ 23 NONAME ; int RPnPServicePublisher::Open(unsigned int)
	?MessagePtr@TControlMessage@@QAEAAVTDes8@@XZ @ 24 NONAME ; class TDes8 & TControlMessage::MessagePtr(void)
	?PnPObserver@RPnPParameterBundle@@QBEPAVMPnPObserver@@XZ @ 25 NONAME ; class MPnPObserver * RPnPParameterBundle::PnPObserver(void) const
	?InitiateControl@RPnPServicePublisher@@QAEHAAVRControlChannel@@@Z @ 26 NONAME ; int RPnPServicePublisher::InitiateControl(class RControlChannel &)
	??1TControlMessage@@QAE@XZ @ 27 NONAME ; TControlMessage::~TControlMessage(void)
	?SetPnPObserver@RPnPParameterBundle@@QAEXPAVMPnPObserver@@@Z @ 28 NONAME ; void RPnPParameterBundle::SetPnPObserver(class MPnPObserver *)
	?SetMessagePtr@TControlMessage@@QAEXAAVTDes8@@@Z @ 29 NONAME ; void TControlMessage::SetMessagePtr(class TDes8 &)
	?CancelRecv@RControlChannel@@QAEXXZ @ 30 NONAME ; void RControlChannel::CancelRecv(void)
	??0RControlChannel@@QAE@XZ @ 31 NONAME ; RControlChannel::RControlChannel(void)
	?RegisterNotify@RPnPServiceDiscovery@@QAEXABVRPnPParameterBundle@@@Z @ 32 NONAME ; void RPnPServiceDiscovery::RegisterNotify(class RPnPParameterBundle const &)
	??0CPnPServicePublisherBase@@IAE@XZ @ 33 NONAME ; CPnPServicePublisherBase::CPnPServicePublisherBase(void)
	?Close@RPnPServiceDiscovery@@QAEXXZ @ 34 NONAME ; void RPnPServiceDiscovery::Close(void)
	?InitiateControl@RPnPServiceDiscovery@@QAEHAAVRControlChannel@@ABVTDesC8@@@Z @ 35 NONAME ; int RPnPServiceDiscovery::InitiateControl(class RControlChannel &, class TDesC8 const &)
	?Send@RControlChannel@@QAEXAAVTControlMessage@@AAVTRequestStatus@@@Z @ 36 NONAME ; void RControlChannel::Send(class TControlMessage &, class TRequestStatus &)
	??0RPnPServicePublisher@@QAE@XZ @ 37 NONAME ; RPnPServicePublisher::RPnPServicePublisher(void)
	?SetMessageDes@TControlMessage@@QAEXABVTDesC8@@@Z @ 38 NONAME ; void TControlMessage::SetMessageDes(class TDesC8 const &)
	??0TControlMessage@@QAE@XZ @ 39 NONAME ; TControlMessage::TControlMessage(void)
	?Describe@RPnPServiceDiscovery@@QAEXABVRPnPParameterBundle@@@Z @ 40 NONAME ; void RPnPServiceDiscovery::Describe(class RPnPParameterBundle const &)

